#include <Sipeed_ST7789.h>
#include "WiFiEsp32.h"

// Emulate Serial1 on pins 6/7 if not present
#ifndef HAVE_HWSERIAL1
#include "SoftwareSerial.h"
SoftwareSerial Serial1(6, 7); // RX, TX
#endif

SPIClass lcd_spi(SPI0); // MUST be SPI0 for Maix series on board LCD
Sipeed_ST7789 lcd(320, 240, lcd_spi);

// the setup routine runs once when you press reset:
void setup() {
  lcd.begin(15000000, COLOR_BLACK);    
  lcd.setRotation(2);
  lcd.setTextSize(2);
  lcd.setTextColor(COLOR_WHITE);
  // initialize serial for debugging
  Serial.begin(115200);
  // initialize serial for ESP module
  Serial1.begin(115200);
  // initialize ESP module
  WiFi.init();

  // check for the presence of the shield
  if (WiFi.status() == WL_NO_SHIELD) {
    Serial.println("WiFi shield not present");
    lcd.print("WiFi shield not present");
    // don't continue
    while (true);
  }

  // Print WiFi MAC address
  printMacAddress();
}

// the loop routine runs over and over again forever:
void loop() {
  lcd.fillScreen(COLOR_BLACK);
  lcd.setCursor(40,10);
  lcd.println("www.cxem.net");
  // scan for existing networks
  Serial.println();
  Serial.println("Scanning available networks...");
  lcd.println();
  lcd.print("Scanning available networks...");
  listNetworks();
  delay(10000);
}
void printMacAddress()
{
  // get your MAC address
  byte mac[6];
  WiFi.macAddress(mac);
  
  // print MAC address
  char buf[20];
  sprintf(buf, "%02X:%02X:%02X:%02X:%02X:%02X", mac[5], mac[4], mac[3], mac[2], mac[1], mac[0]);
  Serial.print("MAC address: ");
  Serial.println(buf);
  lcd.print("MAC address: ");
  lcd.println(buf);
}

void listNetworks()
{
  // scan for nearby networks
  int numSsid = WiFi.scanNetworks();
  if (numSsid == -1) {
    Serial.println("Couldn't get a wifi connection");
    lcd.println("Couldn't get a wifi connection");
    while (true);
  }

  // print the list of networks seen
  Serial.print("Number of available networks:");
  Serial.println(numSsid);
  lcd.print("Number of available networks:");
  lcd.println(numSsid);

  // print the network number and name for each network found
  for (int thisNet = 0; thisNet < numSsid; thisNet++) {
    Serial.print(thisNet);
    Serial.print(") ");
    Serial.print(WiFi.SSID(thisNet));
    Serial.print("\tSignal: ");
    Serial.print(WiFi.RSSI(thisNet));
    Serial.print(" dBm");
    lcd.print(thisNet);
    lcd.print(") ");
    lcd.print(WiFi.SSID(thisNet));
    lcd.print("\tSignal: ");
    lcd.print(WiFi.RSSI(thisNet));
    lcd.print(" dBm");
  }
}
